package Microsoft::AdCenter::V8::AdIntelligenceService::AdPosition;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

=head1 NAME

Microsoft::AdCenter::V8::AdIntelligenceService::AdPosition - Represents "AdPosition" in Microsoft AdCenter Ad Intelligence Service.

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=head1 ENUMERATION VALUES

All
MainLine1
MainLine2
MainLine3
MainLine4
SideBar1
SideBar10
SideBar2
SideBar3
SideBar4
SideBar5
SideBar6
SideBar7
SideBar8
SideBar9

=cut

sub All {
    return 'All';
}

sub MainLine1 {
    return 'MainLine1';
}

sub MainLine2 {
    return 'MainLine2';
}

sub MainLine3 {
    return 'MainLine3';
}

sub MainLine4 {
    return 'MainLine4';
}

sub SideBar1 {
    return 'SideBar1';
}

sub SideBar10 {
    return 'SideBar10';
}

sub SideBar2 {
    return 'SideBar2';
}

sub SideBar3 {
    return 'SideBar3';
}

sub SideBar4 {
    return 'SideBar4';
}

sub SideBar5 {
    return 'SideBar5';
}

sub SideBar6 {
    return 'SideBar6';
}

sub SideBar7 {
    return 'SideBar7';
}

sub SideBar8 {
    return 'SideBar8';
}

sub SideBar9 {
    return 'SideBar9';
}

1;
